@@ -196,10 +196,33 @@ impl PrometheusBuilder {
 
     /// Builds the recorder and exporter and installs them globally.
     ///
+    /// When called from within a Tokio runtime, the handler future is spawned directly
+    /// into the runtime.  Otherwise, a new single-threaded Tokio runtime is created
+    /// on a background thread, and the handler is spawned there.
+    ///
     /// An error will be returned if there's an issue with creating the HTTP server or with
     /// installing the recorder as the global recorder.
     #[cfg(feature = "tokio-exporter")]
     pub fn install(self) -> Result<(), InstallError> {
+        if let Ok(handle) = runtime::Handle::try_current() {
+            let (recorder, exporter) = {
+                let _g = handle.enter();
+                self.build_with_exporter()?
+            };
+            metrics::set_boxed_recorder(Box::new(recorder))?;
+
+            handle.spawn(async move {
+                pin!(exporter);
+                loop {
+                    select! {
+                        _ = &mut exporter => {}
+                    }
+                }
+            });
+
+            return Ok(());
+        }
+
         let runtime = runtime::Builder::new_current_thread()
             .enable_all()
             .build()?;
